@@ -20,6 +20,7 @@
 from persistent import Persistent
 
 from bokeep.book_transaction import \
+    FinancialTransaction, FinancialTransactionLine, \
     BoKeepTransactionNotMappableToFinancialTransaction
 
 from bokeep.util import \
@@ -120,23 +121,51 @@ class BackendDataStateMachine(FunctionAndDataDrivenStateMachine):
         error_code = state_machine.data.get_value('error_code')
         error_string = state_machine.data.get_value('error_string')
         try:
-            fin_trans_list = list(bo_keep_trans.get_financial_transactions())
+            result_of_get_fin_trans = \
+                bo_keep_trans.get_financial_transactions()
+            fin_trans_list = list(result_of_get_fin_trans)
         except BoKeepTransactionNotMappableToFinancialTransaction, e:
             error_code = BackendDataStateMachine.ERROR_OTHER
-            error_string = e.message
+            error_string = str(e)
+        except TypeError, type_e:
+            error_code = BackendDataStateMachine.ERROR_OTHER
+            error_str = \
+                "get_financial_transactions() didn't " \
+                "return a list; stacktrace:\n%s" % (str(type_e),)
         else:
-            try:
-                for fin_trans in fin_trans_list:
-                    new_backend_id = state_machine.backend_plugin.\
-                        create_backend_transaction(fin_trans)
-                    backend_ids_to_fin_trans[new_backend_id] = fin_trans
-                    
-            except BoKeepBackendResetException, reset_e:
-                error_code = BackendDataStateMachine.ERROR_RESET
-                error_string = reset_e.message
-            except BoKeepBackendException, e:
+            # check the FinancialTransaction type
+            if not all( # all conditions are True
+                    isinstance(fin_trans, FinancialTransaction) 
+                    for fin_trans in fin_trans_list ):
                 error_code = BackendDataStateMachine.ERROR_OTHER
-                error_string = e.message
+                error_str = \
+                "get_financial_transactions() returned " \
+                "list/iterable of invalid types"
+            elif not all( # all conditions True
+                    isinstance(fin_trans_line,
+                               FinancialTransactionLine)
+                    for fin_trans in fin_trans_list
+                    for fin_trans_line in fin_trans.lines ):
+                error_code = BackendDataStateMachine.ERROR_OTHER
+                error_str = \
+                "get_financial_transactions() returned " \
+                "FinancialTransaction with some off type " \
+                ".lines "
+            else:
+                try:
+                    for fin_trans in fin_trans_list:
+                        new_backend_id = \
+                            state_machine.backend_plugin.\
+                            create_backend_transaction(fin_trans)
+                        backend_ids_to_fin_trans[new_backend_id] = \
+                            fin_trans
+
+                except BoKeepBackendResetException, reset_e:
+                    error_code = BackendDataStateMachine.ERROR_RESET
+                    error_string = str(reset_e)
+                except BoKeepBackendException, e:
+                    error_code = BackendDataStateMachine.ERROR_OTHER
+                    error_string = str(e)
 
         return state_machine.data.duplicate_and_change(
             backend_ids_to_fin_trans=backend_ids_to_fin_trans,
@@ -168,10 +197,10 @@ class BackendDataStateMachine(FunctionAndDataDrivenStateMachine):
                     break # for loop
             except BoKeepBackendResetException, reset_e:
                 error_code = BackendDataStateMachine.ERROR_RESET
-                error_string = reset_e.message
+                error_string = str(reset_e)
             except BoKeepBackendException, e:
                 error_code = BackendDataStateMachine.ERROR_OTHER
-                error_string = e.message
+                error_string = str(e)
                 break # for loop
 
         return state_machine.data.duplicate_and_change(
@@ -201,10 +230,10 @@ class BackendDataStateMachine(FunctionAndDataDrivenStateMachine):
                 removed_backend_ids.add(backend_id)
         except BoKeepBackendResetException, reset_e:
             error_code = BackendDataStateMachine.ERROR_RESET
-            error_string = reset_e.message
+            error_string = str(reset_e)
         except BoKeepBackendException, e:
             error_code = BackendDataStateMachine.ERROR_CAN_NOT_REMOVE
-            error_string = e.message
+            error_string = str(e)
             for backend_id in removed_backend_ids:
                 del backend_ids_to_fin_trans[backend_id]
         else:
@@ -770,7 +799,7 @@ class RobustBackendPlugin(BackendPlugin):
                     # call close, which also triggers
                     # __set_all_transactions_to_reset_and_advance()
                     self.close('called close() because save failed ' + \
-                                   e.message) 
+                                   str(e)) 
                 else:
                     for dirty_trans_id in self.dirty_transaction_set.iterkeys():
                         self.dirty_transaction_set[dirty_trans_id] = \
@@ -780,9 +809,9 @@ class RobustBackendPlugin(BackendPlugin):
                     self.__advance_all_dirty_transaction_state_machine()
 
             except BoKeepBackendResetException, reset_except:
-                if reset_except.message != '':
+                if str(reset_except) != '':
                     self.__set_all_transactions_to_reset_and_advance(
-                        reset_except.message)
+                        str(reset_except))
                 else:
                     self.__set_all_transactions_to_reset_and_advance()
 
@@ -847,15 +876,6 @@ class RobustBackendPlugin(BackendPlugin):
 
     # TODO convience functions for hold and forced remove
 
-    @ends_with_commit
-    def setattr(self, attr, value):
-        """When this is done, it does a zopedb transaction commit, if you're
-        sharing a zopedb thread with this you'll want to be sure your data
-        is in a state you're comfortable having commited
-        """
-        setattr(self, attr, value)
-        self.flush_backend()
-
     # END MANDATORY BO-KEEP BACKEND PLUGIN API
 
     def front_end_to_back_del(self, key):
