@@ -15,12 +15,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# Author: Mark Jenkins <mark@parit.ca>
+# Authors: Mark Jenkins <mark@parit.ca>
+#          Samuel Pauls <samuel@parit.ca>
 
-# python imports
-from itertools import chain
-
-import ZODB.config
 from persistent import Persistent
 import transaction
 from BTrees.IOBTree import IOBTree
@@ -32,6 +29,10 @@ DEFAULT_BACKEND_MODULE = "bokeep.backend_plugins.null"
 BOOKS_SUB_DB_KEY = 'books'
 
 class BoKeepDBHandle(object):
+    """Wrapper around ZODB database connection for the BoKeep database
+    that adds the concept of sub databases
+    """
+    
     def __init__(self, dbcon):
         self.dbcon = dbcon
         self.dbroot = self.dbcon.root()
@@ -62,6 +63,10 @@ class BoKeepDBHandle(object):
         
 
 class BoKeepBookSet(object):
+    """Aggregates all of the books (BoKeepBook) in a BoKeep database and
+    references a BoKeepDBHandle used to access them.
+    """
+    
     def __init__(self, zodb):
         self.zodb = zodb
         self.dbhandle = self.get_new_dbhandle()
@@ -84,7 +89,7 @@ class BoKeepBookSet(object):
         #flush out whatever's pending
         transaction.get().commit()
         for book_name, book in self.iterbooks():
-            book.get_backend_module().close()
+            book.get_backend_plugin().close()
         self.close_primary_connection()
         self.zodb.close()      
 
@@ -114,64 +119,106 @@ class BoKeepBookSet(object):
         self.dbhandle.get_sub_database_do_cls_init(BOOKS_SUB_DB_KEY, dict)
 
 class BoKeepBook(Persistent):
+    """The equivilent of an accounting book in BoKeep.
+
+    Meaning there should be one of these per entity keeping accounting
+    records of itself.
+
+    Each BoKeep book has frontend plugins (as specified by
+    bokeep.prototype_plugin.ProtoTypePlugin) that provide transaction types.
+    The eventual intent is that there can be multiple
+    frontend plugin INSTANCES per frontend plugin in each book, that way
+    the same frontend plugin can be used multiple times in a book but with
+    a different configuration. Some steps in this direction have been taken,
+    the plugin class from each plugin is instantiated, that is class variables
+    aren't relied on, etc. Biggest barrier to this right now is that the
+    plugin module/package name is used to identify each instance
+
+    Its already the case the separate BoKeepBook's in the same BoKeepBookSet
+    can each use the same frontend plugin, but with a different configuration
+    each.
+
+    Each book contains BoKeep transactions (bokeep.book_transaction.Trasaction)
+    of those transaction types from the frontend plugins. These are
+    indexed by assigned transaction ids in a BTree. (which allows for
+    both fast map style direct lookup and linear, linked list style iteration)
+
+    A book also has a backend plugin so that its transactions can be
+    mirrored in a "real" accounting program. The backend plugin
+    should be informed when a BoKeep transaction
+    (bokeep.book_transaction.Transaction) is out of sync, as per the
+    bokeep.backend_plugins.BackendPlugin api.
+
+    Note that the fact that multiple front end plugins are allowed but only one
+    backend plugin per book isn't an oversight -- the former is essential, the
+    later has no obvious use case. I'd suggest that if someone does want
+    multiple backend plugins per BoKeepBook that they design a Multiplex
+    backend plugin to hide this and allow the simplicity of only dealing
+    with one backend plugin to stay.
+    """
+    
     def __init__(self, new_book_name):
         self.book_name = new_book_name
         self.trans_tree = IOBTree()
-        self.set_backend_module(DEFAULT_BACKEND_MODULE)
+        self.set_backend_plugin(DEFAULT_BACKEND_MODULE)
         self.enabled_modules = {}
         self.disabled_modules = {}
 
-    def add_module(self, module_name):
-        assert( module_name not in self.enabled_modules and 
-                module_name not in self.disabled_modules )
+    def add_frontend_plugin(self, plugin_name):
+        """Add a frontend plugin to this BoKeep book, starting in a disabled
+        state.  FrontendPluginImportError is thrown if there's a problem."""
+        
+        assert( plugin_name not in self.enabled_modules and 
+                plugin_name not in self.disabled_modules )
         # get the module class and instantiate as a new disabled module
         try:
-            self.disabled_modules[module_name] =  __import__(
-                module_name, globals(), locals(), [""]).get_plugin_class()()
+            self.disabled_modules[plugin_name] =  __import__(
+                plugin_name, globals(), locals(), [""]).get_plugin_class()()
             self._p_changed = True
         except ImportError:
-            raise PluginImportError(module_name)
+            raise FrontendPluginImportError(plugin_name)
 
-    def enable_module(self, module_name):
-        assert( module_name in self.disabled_modules )
-        self.enabled_modules[module_name] = self.disabled_modules[module_name]
-        del self.disabled_modules[module_name]
+    def enable_frontend_plugin(self, plugin_name):
+        """Enable a previously added frontend plugin that is currently
+        disabled."""
+        assert( plugin_name in self.disabled_modules )
+        self.enabled_modules[plugin_name] = self.disabled_modules[plugin_name]
+        del self.disabled_modules[plugin_name]
         self._p_changed = True
         
-    def disable_module(self, module_name):
-        assert( module_name in self.enabled_modules )
-        self.disabled_modules[module_name] = self.enabled_modules[module_name]
-        del self.enabled_modules[module_name]
+    def disable_frontend_plugin(self, plugin_name):
+        """Disables a presently enabled frontend plugin."""
+        assert( plugin_name in self.enabled_modules )
+        self.disabled_modules[plugin_name] = self.enabled_modules[plugin_name]
+        del self.enabled_modules[plugin_name]
         self._p_changed = True
     
-    def get_module(self, module_name):
-        return self.enabled_modules[module_name]
+    def get_frontend_plugin(self, plugin_name):
+        return self.enabled_modules[plugin_name]
 
-    def get_modules(self):
+    def get_frontend_plugins(self):
         return self.enabled_modules
 
-    def has_module_enabled(self, module_name):
-        return module_name in self.enabled_modules
+    def has_enabled_frontend_plugin(self, plugin_name):
+        return plugin_name in self.enabled_modules
 
-    def has_module_disabled(self, module_name):
-        return module_name in self.disabled_modules
+    def has_disabled_frontend_plugin(self, plugin_name):
+        return plugin_name in self.disabled_modules
 
-    def has_module(self, module_name):
-        return \
-            self.has_module_enabled(module_name) or \
-            self.has_module_disabled(module_name)
+    def has_frontend_plugin(self, plugin_name):
+        return self.has_enabled_frontend_plugin(plugin_name) or \
+               self.has_disabled_frontend_plugin(plugin_name)
 
     def get_iter_of_code_class_module_tripplets(self):
-        # there has good to be a more functional way to write this..
+        # there has got to be a more functional way to write this..
         # while also maintaining that good ol iterator don't waste memory
         # property... some kind of nice nested generator expressions
         # with some kind of functional/itertool y thing
-        for module in self.enabled_modules.itervalues():
-            for code in module.get_transaction_type_codes():
-                yield (code, module.get_transaction_type_from_code(code),
-                       module)
-            
-        
+        for frontend_plugin in self.enabled_modules.itervalues():
+            for code in frontend_plugin.get_transaction_type_codes():
+                yield (code,
+                       frontend_plugin.get_transaction_type_from_code(code),
+                       frontend_plugin)
 
     def get_index_and_code_class_module_tripplet_for_transaction(
         self, trans_id):
@@ -186,14 +233,14 @@ class BoKeepBook(Persistent):
                 return i, (code, cls, module)
         return None, (None, None, None)
 
-    def set_backend_module(self, backend_module_name):
+    def set_backend_plugin(self, backend_plugin_name):
         if hasattr(self, '_BoKeepBook__backend_module_name'):
-            old_backend_module_name = self.get_backend_module_name()
-            old_backend_module = self.get_backend_module()
+            old_backend_module_name = self.get_backend_plugin_name()
+            old_backend_module = self.get_backend_plugin()
         try:
-            self.__backend_module_name = backend_module_name
+            self.__backend_module_name = backend_plugin_name
             self.__backend_module = __import__(
-              backend_module_name, globals(), locals(), [""] ).\
+              backend_plugin_name, globals(), locals(), [""] ).\
     	      get_plugin_class()()
             assert( isinstance(self.__backend_module, BackendPlugin) )
             # because we have changed the backend module, all transactions
@@ -207,17 +254,19 @@ class BoKeepBook(Persistent):
             # but that should only happen on book instantiation
             self.__backend_module_name = old_backend_module_name
             self.__backend_module = old_backend_module  
-            raise BackendPluginImportError(backend_module_name)
+            raise BackendPluginImportError(backend_plugin_name)
 
-    def get_backend_module(self):
+    def get_backend_plugin(self):
         return self.__backend_module
 
-    def get_backend_module_name(self):
+    def get_backend_plugin_name(self):
         return self.__backend_module_name
 
-    backend_module = property(get_backend_module, set_backend_module)
+    backend_plugin = property(get_backend_plugin, set_backend_plugin)
 
     def insert_transaction(self, trans):
+        """Adds a transaction to this BoKeep book."""
+        
         if len(self.trans_tree) == 0:
             largest_in_current = -1
         else:
@@ -255,6 +304,8 @@ class BoKeepBook(Persistent):
         return trans_id > self.trans_tree.minKey()
 
     def get_next_trans(self, trans_id):
+        """Returns the key of the next transaction or None."""
+        
         if not self.has_transaction(trans_id):
             return None
         try:
@@ -275,9 +326,9 @@ class BoKeepBook(Persistent):
 
     def remove_transaction(self, trans_id):
         del self.trans_tree[trans_id]
-        self.backend_module.mark_transaction_for_removal(trans_id)
+        self.backend_plugin.mark_transaction_for_removal(trans_id)
 
-class PluginImportError(Exception):
+class FrontendPluginImportError(Exception):
     def __init__(self, plugin_name):
         if type(plugin_name) == str:
             Exception.__init__(self, "%s: missing or broken" % plugin_name)
