@@ -21,9 +21,8 @@
 
 # python imports
 from os.path import \
-    exists, isdir, isfile, basename, split as path_split, join as path_join, abspath
+    exists, isdir, join as path_join
 import os
-from os import makedirs
 import sys
 from sys import path
 
@@ -45,12 +44,11 @@ from gtk import \
 
 # bokeep imports
 from bokeep.config import \
-    BoKeepConfigurationDatabaseException, get_bokeep_configuration, \
-    DEFAULT_BOOKS_FILESTORAGE_FILE, ZODB_CONFIG_SECTION, \
-    ZODB_CONFIG_FILESTORAGE, ZODB_CONFIG_ZCONFIG, \
-    get_plugins_directories_from_config, set_plugin_directories_in_config
-from bokeep.book import BoKeepBookSet, \
-    PluginImportError, BackendPluginImportError
+    BoKeepConfigurationDatabaseException, ZODB_CONFIG_SECTION, \
+    ZODB_CONFIG_FILESTORAGE, get_plugins_directories_from_config, \
+    set_plugin_directories_in_config, \
+    ZODB_CONFIG_ZCONFIG
+from bokeep.book import BoKeepBookSet, FrontendPluginImportError
 from bokeep.gui.main_window_glade import get_main_window_glade_file
 from bokeep.gui.gladesupport.glade_util import \
     load_glade_file_get_widgets_and_connect_signals
@@ -61,9 +59,29 @@ from state import BoKeepConfigGuiState, \
     BOOK
 
 def establish_bokeep_db(mainwindow, config_path, config, db_exception):
-    """TODO: Write this doc string!  (What this function is responsible for is
-    unclear to at least one contributor :P ) e.g. establish = create or load?"""
-    
+    """Dialog to edit the configuration settings for a BoKeep database, 
+    create it at the configured location if not there yet, and also
+    exercise control over other settings kept in the bokeep configuration
+    (.bo-keep.cfg), and basic things like creating books and enabling
+    plugins.
+
+    And the best part is that a BoKeepBookSet for whichever database
+    you choose to select (in this dialog) is returned or None
+    if this fails
+
+    mainwindow -- if there's a Gtk.Window we can parrent this dialog too,
+                  please provide it, otherwise set to None
+    config_path -- path the configuration file is found at
+    config     -- a  ConfigParser.ConfigParser pre-loaded with the contents
+                  of config_path .
+    db_exception -- If you experienced some kind of exception while
+                    trying to load the BoKeepBookSet without the help of a
+                    this function, pass it on to us so we can display
+                    the error to the user so they know why they're
+                    being forced into a gui to fix things up
+
+    Changes made to config are saved in config_path
+    """
     assert(db_exception == None or
            isinstance(db_exception, BoKeepConfigurationDatabaseException))
     if db_exception == None:
@@ -109,10 +127,10 @@ def establish_bokeep_db(mainwindow, config_path, config, db_exception):
     elif new_db_access_method == ZODB_CONFIG_ZCONFIG:
         return BoKeepBookSet(databaseFromURL(new_db_path))
 
-def available_plugins():
+def get_available_frontend_plugins():
     return available_plugins_search("BOKEEP_PLUGIN", "plugins")
 
-def available_backend_plugins():
+def get_available_backend_plugins():
     return available_plugins_search("BOKEEP_BACKEND_PLUGIN", "backend_plugins")
 
 def available_plugins_search(plugin_file_name, plugin_subdir):
@@ -173,6 +191,8 @@ def available_plugins_search(plugin_file_name, plugin_subdir):
     return bokeep_packages + bokeep_modules
 
 class BoKeepConfigDialog(object):
+    """GUI for configuring BoKeep."""
+    
     config_path = None
     config = None
     
@@ -188,7 +208,8 @@ class BoKeepConfigDialog(object):
             self, self)
         self.selection_change_lock = True
 
-        self.state = BoKeepConfigGuiState(error_msg)
+        self.state = BoKeepConfigGuiState(
+            error_msg, self.__force_config_on_newly_created_plugin)
         self.books_tv = TreeView(self.state.book_liststore)
         self.books_tv.append_column(
                 TreeViewColumn("Book", CellRendererText(), text=0 ) )
@@ -196,7 +217,7 @@ class BoKeepConfigDialog(object):
             "changed", self.on_book_selection_change)
         self.books_window.add(self.books_tv)
         self.books_tv.show()
-        self.plugins_tv = TreeView(self.state.plugin_liststore)
+        self.plugins_tv = TreeView(self.state.frontend_plugin_liststore)
         self.plugins_tv.append_column(
             TreeViewColumn("Plugin", CellRendererText(), text=0) )
         crt = CellRendererToggle()
@@ -232,43 +253,50 @@ class BoKeepConfigDialog(object):
         """Populates the GUI with the possible front and backend plugins."""
         
         available_plugin_liststore = ListStore(str)
-        for plugin_name in available_plugins():
+        for plugin_name in get_available_frontend_plugins():
             available_plugin_liststore.append([plugin_name])
         self.plugin_add_entry_combo.set_model(available_plugin_liststore)
         self.plugin_add_entry_combo.set_text_column(0)
 
         available_backend_plugin_liststore = ListStore(str)
-        for backend_plugin_name in available_backend_plugins():
+        for backend_plugin_name in get_available_backend_plugins():
             available_backend_plugin_liststore.append([backend_plugin_name])
         self.backend_plugin_entry_combo.set_model(available_backend_plugin_liststore)
         self.backend_plugin_entry_combo.set_text_column(0)
 
     def do_action(self, action, arg=None):
+        """Passes on an action to BoKeepConfigGuiState and gui is then
+        updated after to reflect the effects of that action by examining
+        where that state machine is at after the action.
+        """
+        
         try:
             self.state.do_action(action, arg)
-        except PluginImportError, err:
+        except FrontendPluginImportError, err:
             backend_plugin_entry = self.backend_plugin_entry_combo.child
             backend_plugin_name = backend_plugin_entry.get_text()
             if backend_plugin_name in err.plugin_names:
                 self.backend_plugin_entry_combo.child.set_text(
-                        self.state.data[BOOK].get_backend_module_name() )
+                        self.state.data[BOOK].get_backend_plugin_name() )
                 err.plugin_names.remove(backend_plugin_name)
 
             frontend_plugins = {}
-            for name, enabled in self.state.plugin_liststore:
+            for name, enabled in self.state.frontend_plugin_liststore:
                 frontend_plugins[name] = (name, enabled)
 
             for err_plugin_name in err.plugin_names:
                 del frontend_plugins[err_plugin_name]
 
-            self.state.plugin_liststore.clear()
+            self.state.frontend_plugin_liststore.clear()
             for valid_plugin_name, enabled in frontend_plugins.values():
-                self.state.plugin_liststore.append((valid_plugin_name, enabled))
+                self.state.frontend_plugin_liststore.append((valid_plugin_name, enabled))
 
             error_dialog = MessageDialog(self.bokeep_config_dialog, DIALOG_MODAL, 
                            MESSAGE_ERROR, BUTTONS_OK, str(err))
             error_dialog.run()
             error_dialog.destroy()
+            # raises last exception that had been caught, in above
+            # except clause, err
             raise
 
 
@@ -280,6 +308,9 @@ class BoKeepConfigDialog(object):
         return db_access_method
 
     def run(self):
+        """Run the BoKeep configuration dialog so the user can interact with
+        it."""
+        
         self.bokeep_config_dialog.run()
         if self.state.action_allowed(BOOK_CHANGE):
             self.do_action(BOOK_CHANGE, None)
@@ -293,6 +324,8 @@ class BoKeepConfigDialog(object):
         return RESPONSE_OK, db_path, db_access_method
 
     def set_sensitivities(self):
+        """Set the enabled/disabled property of all config widgets."""
+        
         for obj, action in (
             (self.books_tv, BOOK_CHANGE),
             (self.book_add_entry, BOOK_CHANGE),
@@ -305,6 +338,8 @@ class BoKeepConfigDialog(object):
             obj.set_sensitive( self.state.action_allowed(action) )
 
     def get_currently_selected_book(self, *args):
+        """Return the currently selected book in the configuration dialog."""
+        
         sel = self.books_tv.get_selection()
         sel_iter = sel.get_selected()[1]
         if sel_iter == None:
@@ -314,6 +349,8 @@ class BoKeepConfigDialog(object):
             return sel_row[0]
 
     def select_book(self, new_book):
+        """Visually select a given book in the configuration dialog."""
+        
         selection = self.books_tv.get_selection()
         selection.unselect_all()
         for path, book in enumerate(self.state.book_liststore):
@@ -324,6 +361,8 @@ class BoKeepConfigDialog(object):
     # event handles
 
     def on_selectdb_button_clicked(self, *args):
+        """Browse for the location of a new BoKeep transaction database."""
+        
         fcd = FileChooserDialog(
             "Where should the database be?",
             self.bokeep_config_dialog,
@@ -357,7 +396,7 @@ class BoKeepConfigDialog(object):
 
     def on_plugin_add_clicked(self, *args):
         entry = self.plugin_add_entry_combo.child
-        self.state.plugin_liststore.append((entry.get_text(), True))
+        self.state.frontend_plugin_liststore.append((entry.get_text(), True))
         entry.set_text("")
 
     def on_backend_plugin_entry_combo_changed(self, *args):
@@ -371,7 +410,7 @@ class BoKeepConfigDialog(object):
             if sel_book == None:
                 try:
                     self.do_action(BOOK_CHANGE, None)
-                except PluginImportError:
+                except FrontendPluginImportError:
                     self.select_book(self.state.data[BOOK])
                 else:
                     self.backend_entry_lock = True
@@ -380,12 +419,12 @@ class BoKeepConfigDialog(object):
             else:
                 try:
                     self.do_action(BOOK_CHANGE, sel_book)
-                except PluginImportError:
+                except FrontendPluginImportError:
                     self.select_book(self.state.data[BOOK])
                 else:
                     self.backend_entry_lock = True
                     self.backend_plugin_entry_combo.child.set_text(
-                        self.state.data[BOOK].get_backend_module_name() )
+                        self.state.data[BOOK].get_backend_plugin_name() )
                     self.backend_entry_lock = False
             self.set_sensitivities()
             
@@ -546,3 +585,18 @@ class BoKeepConfigDialog(object):
         # selected.
         if iter != None:
             remove_button.set_sensitive(True)
+
+    def __force_config_on_newly_created_plugin(self, book, is_backend, new_plugin):
+        """Configures a newly added frontend plugin.
+        
+        book: The BoKeep book that the plugin is used in.
+        is_backend: True if it's a backend plugin, False if frontend.
+        new_plugin: The new plugin that needs configuring."""
+        
+        if is_backend:
+            new_plugin.configure_backend(self.bokeep_config_dialog)
+        else:
+            new_plugin.run_configuration_interface(
+                self.bokeep_config_dialog,
+                book.get_backend_plugin().backend_account_dialog,
+                book)
\ No newline at end of file
