@@ -18,8 +18,8 @@
 #            Samuel Pauls <samuel@parit.ca>
 
 JUL_2006, JAN_2007, JAN_2008, JAN_2009, APR_2009, JAN_2010, JAN_2011, \
-JUL_2011 = range(8)
-LAST_RULE_PERIOD = JUL_2011
+JUL_2011, JAN_2012 = range(9)
+LAST_RULE_PERIOD = JAN_2012
 
 # dictionary where each period is a key and the vaule is a two element tuple 
 # consisting of the year part and the month part
@@ -36,8 +36,11 @@ CODE_TO_YEAR_AND_MONTHS = { JUL_2006: (2006, range(7, 12+1) ),
                             JAN_2009: (2009, range(1, 3+1) ),
                             APR_2009: (2009, range(4, 12+1) ),
                             JAN_2010: (2010, range(1, 12+1) ),
-                            JAN_2011: (2011, range(1, 12+1) ),
+                            JAN_2011: (2011, range(1, 6+1) ),
                             JUL_2011: (2011, range(7, 12+1) ),
+                            # note: change this to 1, 6+1 if a JUL entry
+                            # is added
+                            JAN_2012: (2012, range(1, 12+1) ), 
                             }
 
 YEAR_AND_MONTH_TO_CODE = {}
