@@ -18,12 +18,43 @@
 # Author: Mark Jenkins <mark@parit.ca
 
 def get_plugin_class():
+    """Returns a class that's instantiated as part of the process of
+    loading a front end plugin into a BoKeepBook.
+
+    Right now, the class returned here is only instantiated once per book,
+    but eventually a book will be able to make multiple instances.
+
+    Implication of both of both situations above is that there shouldn't
+    be things stored in class variables of this class, each instance
+    of what's returned here should be isolated from the other datawise.
+    
+    Every front end plugin should define this function in its main
+    module or __init__.py of its top level package.
+    """    
     return PrototypePlugin
 
 from persistent import Persistent
 from bokeep.book_transaction import Transaction
 
 class PrototypePlugin(Persistent):
+    """A plugin that documents all of the required frontend plugin api methods
+
+    BoKeep frontend plugins need not inherit from this, but if they do
+    they get some default methods in many cases which do the minimum
+    required to get by, so inheriting from PrototypePlugin can be a way
+    to get started -- before you end up overloading all of these methods
+    (and you're pretty much gaurenteed to) it can help you get a *prototype*
+    going that respects the full BoKeep api and doesn't crash.
+
+    And that's really only useful if your plan is to directly implement the full
+    BoKeep api that's documented here.
+
+    Almost all plugin developers would get a much more satisfactory experience
+    inheriting from bokeep.simple_plugin.SimplePlugin, which hides most of
+    the cool dymaic power of the BoKeep plugin api here and just covers
+    the really comomon cases fairly well.
+    """
+    
     def run_configuration_interface(self, parent_window, backend_account_fetch,
                                     book):
         """Instructs a plugin to run a configuration dialog
@@ -132,13 +163,17 @@ class PrototypePlugin(Persistent):
             should be ready to either provide something or raise
             bokeep.book_transaction.
             BoKeepTransactionNotMappableToFinancialTransaction
+
+          - bokeep.book.BoKeepBook where the transaction and plugin
+            instance come from
           
         The function returned here should return an instance of something
         representing the edditing session. This instance must implement
         a detach() method which removes the gtk elements added
         with gui_parent.pack_end()
         """
-        def blah(trans, transid, plugin, gui_parent, change_register_function):
+        def blah(trans, transid, plugin, gui_parent, change_register_function,
+                 book):
             class blah_cls(object):
                 def detach(self):
                     pass
@@ -166,3 +201,51 @@ class PrototypePlugin(Persistent):
         """
         
         return self.get_transaction_edit_interface_hook_from_code(code)
+
+    def get_transaction_display_by_mode_hook(self, code):
+        """The new BoKeep shell to front end plugin api will go through this
+        instead of old get_transaction_edit_interface_hook_from_code and
+        get_transaction_view_interface_hook_from_code .
+
+        Those two old functions will be deprecated in BoKeep 1.2.0
+
+        Like the old function, get_transaction_display_by_mode_hook returns
+        a callable, which shells will call with the following old arguments
+        familiar from before:
+        
+        trans - BoKeep.book_transaction.Transaction 
+        transid - unique, identifying integer
+        plugin  - The plugin instance in use
+        gui_parent - The widget in the shell the plugin should display itself in
+        change_register_function - A function the plugin should call to inform
+                                   the shell that persistable objects in the
+                                   transaction and plugin have changed
+        book - The BoKeepBook the plugin instance belongs to
+
+        The new arguments for get_transaction_display_by_mode_hook are
+        display_mode - A constant instructing the plugin how it should
+                       behave, mostly in in terms of what is or isn't editable,
+                       but also for indicating if the shell is headless.
+                       These are documented in bokeep.shells.
+        transaction_edit_finished_function - when display_mode is set to
+           TRANSACTION_ALL_EDIT_FIRST_TIME_HEADLESS,
+           TRANSACTION_ALL_EDIT_HEADLESS,
+           TRANSACTION_WITH_ESSENTIALS_READ_ONLY_HEADLESS,
+           TRANSACTION_READ_ONLY_HEADLESS, it means the shell is headless
+           (has no visible gui, just window border), so the plugin itself
+           needs to provide some kind of user interface element so the user
+           can say they're done the current transaction so the headless shell
+           can know it can move on to the next one.
+
+
+        AAHHHH!, This docstring needs to be merged with the still applicable
+        elements from get_transaction_view_interface_hook_from_code and
+        get_transaction_view_interface_hook_from_code
+        """
+        def blah(trans, transid, plugin, gui_parent, change_register_function,
+                 main, display_mode, transaction_edit_finished_function):
+            class blah_cls(object):
+                def detach(self):
+                    pass
+            return blah_cls()
+        return blah
