@@ -30,6 +30,7 @@ from itertools import chain
 # ZODB
 import transaction
 from persistent import Persistent
+from persistent.list import PersistentList
 
 # simplifies common usage of transaction.get().commit()
 def ends_with_commit(dec_function):
@@ -490,6 +491,9 @@ def reload_module_at_filepath(module, path):
     reload(module)
     drop_syspath_enhancement()
 
+def do_module_import(module_name):
+    return __import__(module_name, globals(), locals(), [""])
+
 class PluginSet(Persistent):
     def __init__(self):
         self.enabled_plugins = {}
@@ -499,8 +503,8 @@ class PluginSet(Persistent):
         assert( plugin_name not in self.enabled_plugins and 
                 plugin_name not in self.disabled_plugins )
         # get the plugin class and instantiate as a new disabled plugin
-        self.disabled_plugins[plugin_name] =  __import__(
-            plugin_name, globals(), locals(), [""]).get_plugin_class()()
+        self.disabled_plugins[plugin_name] =  do_module_import(
+            plugin_name).get_plugin_class()()
         self._p_changed = True
 
     def enable_plugin(self, plugin_name):
@@ -611,8 +615,79 @@ def decimal_truncate_two_places(decimal_value):
     # with negative numbers
     return decimal_value.quantize(TWOPLACES, rounding=ROUND_DOWN)
 
-def tup_chain(*args):
-    return tuple(chain(*args))
+class SubList(Persistent):
+    def __init__(self, parallel_list):
+        # The "outer" list, the begger one that our sub list will
+        # have items in
+        self.parallel_list = parallel_list
 
-def tup_multi_append(original_tuple, *args):
-    return tup_chain(original_tuple, args)
+        # the actual sub list of items that will also be kept in the
+        # parallell/outer list. Aditional feature some day would be a
+        # way to initialize this to be certain items already in the bigger
+        # parallel list
+        self.inner_sub_list = PersistentList()
+        self.paranoia = False
+        
+    def append(self, item):
+        self.inner_sub_list.append( (len(self.parallel_list), item) )
+        # important to do second because len(self.parallel_list) above
+        # is meant to be in the position being inserted into here...
+        self.parallel_list.append(item)
+        self.verify_integrity_if_paranoid()
+
+    def __delitem__(self, index):
+        del self.parallel_list[ self.inner_sub_list[index][0] ]
+        # reconstruct the inner sublist, items prior to index have the
+        # same index in the outer
+        self.inner_sub_list = PersistentList(
+            ((outer_i if i < index else outer_i-1 ),
+             item )
+            for i, (outer_i, item) in enumerate(self.inner_sub_list)
+            if i != index
+            )
+        self.verify_integrity_if_paranoid()
+
+    def __iter__(self):
+        self.verify_integrity_if_paranoid()
+        return iter( item for outer_i, item in self.inner_sub_list )
+
+    def verify_integrity(self):
+        return all( id(item) == id(self.parallel_list[outer_i])
+                    for outer_i, item in self.inner_sub_list )
+        
+    def verify_integrity_if_paranoid(self):
+        assert( True if not self.paranoia
+                else self.verify_integrity() )
+
+    def __len__(self):
+        return len(self.inner_sub_list)
+
+class DumbMemLeakingUUIDLookup(object):
+    def __init__(self):
+        self.table = []
+    
+    def create(self):
+        uuid = len(self.table)
+        self.table.append(None)
+        return uuid
+    
+    def lookup(self, uuid):
+        return self.table[uuid]
+    
+    def set(self, uuid, value):
+        self.table[uuid] = value
+
+    def create_and_set(self, value):
+        uuid = self.create()
+        self.set(uuid, value)
+        return uuid
+
+    def clear(self, uuid):
+        self.set(uuid, None)
+
+def iterable_linear_search(iterable, conditional):
+    # warning, you should expect conditional to return True for something
+    # in the iterable
+    return (i
+            for i,iter_val in enumerate(iterable)
+            if conditional(iter_val) ).next()
