@@ -122,7 +122,7 @@ FAILURE_TYPES = \
     (REMOVAL_FAIL, REMOVAL_RESET, CREATION_FAIL, CREATION_RESET,
      SAVE_FAIL, SAVE_RESET, VERIFY_FAIL, VERIFY_RESET) = range(8)
 
-class BackendModuleUnitTest(TestHackableClass, RobustBackendPlugin):
+class BackendPluginUnitTest(TestHackableClass, RobustBackendPlugin):
     def __init__(self):
         RobustBackendPlugin.__init__(self)
         TestHackableClass.__init__(self)
@@ -164,7 +164,7 @@ class BackendModuleUnitTest(TestHackableClass, RobustBackendPlugin):
         SAVE)
     close = create_logging_function(RobustBackendPlugin.close, CLOSE)
 
-class BackendModuleBasicSetup(TestCase):
+class BackendPluginBasicSetup(TestCase):
     """This tests that RobustBackendPlugin makes calls to the subclass functions
     create_backend_transaction, remove_backend_transaction,
     verify_backend_transaction, save, and close in the expected order, and
@@ -175,12 +175,12 @@ class BackendModuleBasicSetup(TestCase):
     backend_reset_occured
     """
     def setUp(self):
-        self.backend_module = BackendModuleUnitTest()
+        self.backend_plugin = BackendPluginUnitTest()
         self.transaction = TestTransaction()
         self.fin_trans = self.transaction.get_financial_transactions()[0]
 
     def pop_all_look_for_save(self):
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 1)
         self.look_for_save(actions)
         
@@ -217,7 +217,7 @@ class BackendModuleBasicSetup(TestCase):
         self.assertEquals(transaction, fin_trans)
 
     def look_for_empty_actions_queue(self):
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 0)        
 
     def assertBackendException(self, callable, *args, **kargs):
@@ -226,34 +226,34 @@ class BackendModuleBasicSetup(TestCase):
 
     def assertTransactionIsCleanFail(self, trans_id):
         self.assertBackendException(
-            self.backend_module.transaction_is_clean,
+            self.backend_plugin.transaction_is_clean,
             trans_id )
 
     def assertTransactionIsClean(self, trans_id):
         self.assert_(
-            self.backend_module.transaction_is_clean(trans_id))
+            self.backend_plugin.transaction_is_clean(trans_id))
         # this should not throw an exception, idealy we'd check that
         # it always returns None instead of a string, but we're not
         # too worried about forcing that, a backend implementation
         # doesn't need to do that...
         self.assertRaises(
             BoKeepBackendException,
-            self.backend_module.reason_transaction_is_dirty,
+            self.backend_plugin.reason_transaction_is_dirty,
             trans_id )
 
     def assertTransactionIsDirty(self, trans_id):
         self.assertFalse(
-            self.backend_module.transaction_is_clean(trans_id))
+            self.backend_plugin.transaction_is_clean(trans_id))
 
         self.assert_( isinstance(
-                self.backend_module.reason_transaction_is_dirty(trans_id),
+                self.backend_plugin.reason_transaction_is_dirty(trans_id),
                 str ) )
 
-class BasicBackendModuleTest(BackendModuleBasicSetup):
+class BasicBackendPluginTest(BackendPluginBasicSetup):
     def test_null_reset(self):
         # hmm, still saves even if no changes, might want to change that
         # someday
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.pop_all_look_for_save()
 
     def test_clean_check_on_none(self):
@@ -262,41 +262,41 @@ class BasicBackendModuleTest(BackendModuleBasicSetup):
     def test_verify_fail_on_none(self):
         self.assertRaises(
             BoKeepBackendException,
-            self.backend_module.mark_transaction_for_verification,
+            self.backend_plugin.mark_transaction_for_verification,
             None )
 
     def test_remove_fail_on_none(self):
         self.assertRaises(
             BoKeepBackendException,
-            self.backend_module.mark_transaction_for_removal,
+            self.backend_plugin.mark_transaction_for_removal,
             None )
 
     def test_forced_remove_of_non_existent_transaction(self):
         self.assertRaises(
             BoKeepBackendException,
-            self.backend_module.mark_transaction_for_forced_remove,
+            self.backend_plugin.mark_transaction_for_forced_remove,
             None )
 
     def test_hold_on_non_existent_transaction(self):
         self.assertRaises(
             BoKeepBackendException,
-            self.backend_module.mark_transaction_for_hold,
+            self.backend_plugin.mark_transaction_for_hold,
             None )
 
-class StartWithInsertSetup(BackendModuleBasicSetup):
+class StartWithInsertSetup(BackendPluginBasicSetup):
     def setUp(self):
-        BackendModuleBasicSetup.setUp(self)
+        BackendPluginBasicSetup.setUp(self)
         self.front_end_id = 0
-        self.backend_module.mark_transaction_dirty(
+        self.backend_plugin.mark_transaction_dirty(
             self.front_end_id, self.transaction)
         self.FIRST_BACKEND_ID = 1
 
     def force_remove_known_transaction(self):
-        self.backend_module.mark_transaction_for_forced_remove(
+        self.backend_plugin.mark_transaction_for_forced_remove(
             self.front_end_id)
 
     def verify_known_transaction(self):
-        self.backend_module.mark_transaction_for_verification(
+        self.backend_plugin.mark_transaction_for_verification(
             self.front_end_id)        
 
     # not an actual test case, has to be called by a function
@@ -307,7 +307,7 @@ class StartWithInsertSetup(BackendModuleBasicSetup):
             self.force_remove_known_transaction)
 
     def run_inspection_of_create_save(self, backend_id=None):
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 2) # create, save
         self.look_for_create(actions, backend_id, self.fin_trans )
         self.look_for_save(actions)
@@ -315,18 +315,18 @@ class StartWithInsertSetup(BackendModuleBasicSetup):
 class StartWithInsertTest(StartWithInsertSetup):
     def test_fin_trans_none(self):
         self.transaction.program_return(0, None)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
 
     def test_fin_trans_wrong_type(self):
         self.transaction.program_return(0, (None,) )
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
     
     def test_fin_trans_wrong_lines_type(self):
         self.transaction.program_return(0, (
                 FinancialTransaction( (None,) ) ) )
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         
     def test_initial_dirtyness(self):
@@ -336,9 +336,9 @@ class StartWithInsertTest(StartWithInsertSetup):
         self.run_test_of_forced_remove_of_non_held_transaction()
 
     def test_hold_of_uncommited_new_transaction(self):
-        self.backend_module.mark_transaction_for_hold(self.front_end_id)
+        self.backend_plugin.mark_transaction_for_hold(self.front_end_id)
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         # this should just save, in the future, we might even avoid the
         # wasted save here
@@ -352,19 +352,19 @@ class StartWithInsertTest(StartWithInsertSetup):
     def test_re_insert_trouble_when_change(self):
         self.assertRaises(
             BoKeepBackendException,
-            self.backend_module.mark_transaction_dirty,
+            self.backend_plugin.mark_transaction_dirty,
             self.front_end_id, None
             )
 
     def test_remove_right_after_insert(self):
-        self.backend_module.mark_transaction_for_removal(self.front_end_id)
+        self.backend_plugin.mark_transaction_for_removal(self.front_end_id)
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsCleanFail(self.front_end_id)
         self.pop_all_look_for_save()
 
     def test_create(self):
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsClean(self.front_end_id)
         self.run_inspection_of_create_save(self.FIRST_BACKEND_ID)
 
@@ -372,10 +372,10 @@ class StartWithInsertTest(StartWithInsertSetup):
         def check_for_right_financial_trans(backend_mod_self, fin_trans):
             return self.fin_trans == fin_trans
         
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             CREATION_FAIL, BoKeepBackendException,
             "creation fail", check_for_right_financial_trans)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         self.run_inspection_of_create_save(None)
         # creation process should work now that programmed fail is gone
@@ -385,12 +385,12 @@ class StartWithInsertTest(StartWithInsertSetup):
         def check_for_right_financial_trans(backend_mod_self, fin_trans):
             return self.fin_trans == fin_trans
         
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             CREATION_RESET, BoKeepBackendResetException,
             "creation lost to reset", check_for_right_financial_trans)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)        
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 1) # create
         self.look_for_create(actions, None, self.fin_trans )
         # creation process should work now that programmed reset is gone
@@ -400,20 +400,20 @@ class StartWithInsertTest(StartWithInsertSetup):
         def check_for_right_financial_trans(backend_mod_self, fin_trans):
             return self.fin_trans == fin_trans
         
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             CREATION_FAIL, BoKeepBackendException,
             "creation fail", check_for_right_financial_trans)
 
         reason_for_reset = "reset called on save()"
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             SAVE_RESET, BoKeepBackendResetException,
             reason_for_reset, lambda backend_mod_self: True )
 
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         self.run_inspection_of_create_save(backend_id=None)
         full_error_string = \
-            self.backend_module.reason_transaction_is_dirty(self.front_end_id)
+            self.backend_plugin.reason_transaction_is_dirty(self.front_end_id)
         self.assert_(full_error_string.endswith(reason_for_reset) )
         self.assert_(full_error_string.startswith(
             "error code: %s"  % BackendDataStateMachine.ERROR_RESET) )
@@ -427,22 +427,22 @@ class StartWithTwoInsertAndSetup(StartWithInsertSetup):
         self.fin_trans2 = self.transaction2.get_financial_transactions()[0]
         assert(self.fin_trans2 != self.fin_trans)
         self.front_end_id_2 = 1
-        self.backend_module.mark_transaction_dirty(
+        self.backend_plugin.mark_transaction_dirty(
             self.front_end_id_2, self.transaction2)
         self.SECOND_BACKEND_ID = 2
 
     def test_double_create_where_second_one_kills_first_with_reset(self):
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsClean(self.front_end_id)
         self.assertTransactionIsClean(self.front_end_id_2)
-        self.backend_module.pop_actions_queue()
-        self.backend_module.mark_transaction_dirty(
+        self.backend_plugin.pop_actions_queue()
+        self.backend_plugin.mark_transaction_dirty(
             self.front_end_id, self.transaction)
-        self.backend_module.mark_transaction_dirty(
+        self.backend_plugin.mark_transaction_dirty(
             self.front_end_id_2, self.transaction2)
-        self.backend_module.flush_backend()        
+        self.backend_plugin.flush_backend()        
 
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 7)
         cmd, return_val, backend_ident, fin_trans = actions.pop()
         if fin_trans == self.fin_trans:
@@ -457,17 +457,17 @@ class StartWithTwoInsertAndSetup(StartWithInsertSetup):
         def check_for_right_financial_trans(backend_mod_self, fin_trans_in):
             return second_fin_trans_recreate == fin_trans_in
         
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             CREATION_RESET, BoKeepBackendResetException,
             "creation lost to reset", check_for_right_financial_trans)
-        self.backend_module.mark_transaction_dirty(
+        self.backend_plugin.mark_transaction_dirty(
             self.front_end_id, self.transaction)
-        self.backend_module.mark_transaction_dirty(
+        self.backend_plugin.mark_transaction_dirty(
             self.front_end_id_2, self.transaction2)
         self.assertTransactionIsDirty(self.front_end_id)
         self.assertTransactionIsDirty(self.front_end_id_2)
-        self.backend_module.flush_backend()
-        actions = self.backend_module.pop_actions_queue()        
+        self.backend_plugin.flush_backend()
+        actions = self.backend_plugin.pop_actions_queue()        
         self.assertEquals(len(actions), 6)
         self.look_for_verify(actions, first_fin_trans_recreate, True,
                              3)
@@ -480,10 +480,10 @@ class StartWithTwoInsertAndSetup(StartWithInsertSetup):
         
         self.assertTransactionIsDirty(self.front_end_id)
         self.assertTransactionIsDirty(self.front_end_id_2)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsClean(self.front_end_id)
         self.assertTransactionIsClean(self.front_end_id_2)
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 7)
         self.look_for_verify(actions, first_fin_trans_recreate, True,
                              3)
@@ -497,28 +497,28 @@ class StartWithTwoInsertAndSetup(StartWithInsertSetup):
 class StartWithInsertAndFlushSetup(StartWithInsertSetup):
     def setUp(self):
         StartWithInsertSetup.setUp(self)
-        self.backend_module.flush_backend()
-        self.backend_module.pop_actions_queue()
+        self.backend_plugin.flush_backend()
+        self.backend_plugin.pop_actions_queue()
         self.SECOND_BACKEND_ID = self.FIRST_BACKEND_ID+1
 
     def run_test_of_transaction_verify(self, verify_result=True):
         # this should do a VERIFY and a SAVE
         self.verify_known_transaction()
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsClean(self.front_end_id)
         self.look_for_actions_from_verify(verify_result)
 
     def look_for_actions_from_verify(self, verify_result=True):
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 2) # verify, save
         self.look_for_verify(actions, self.fin_trans, verify_result)
         self.look_for_save(actions)        
 
     def remove_known_transaction_and_flush(self):
-        self.backend_module.mark_transaction_for_removal(self.front_end_id)
+        self.backend_plugin.mark_transaction_for_removal(self.front_end_id)
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
 
     def run_test_of_transaction_remove(self):
         self.remove_known_transaction_and_flush()
@@ -526,7 +526,7 @@ class StartWithInsertAndFlushSetup(StartWithInsertSetup):
         self.look_for_normal_remove_sequence()
 
     def look_for_normal_remove_sequence(self):
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 3) # verify, remove, save
         self.look_for_verify(actions, self.fin_trans)
         self.look_for_remove(actions, self.FIRST_BACKEND_ID)
@@ -535,13 +535,13 @@ class StartWithInsertAndFlushSetup(StartWithInsertSetup):
     def run_test_fail_if_dirty_mark_in_hold(self):
         self.assertRaises(
             BoKeepBackendException,
-            self.backend_module.mark_transaction_dirty,
+            self.backend_plugin.mark_transaction_dirty,
             self.front_end_id, self.transaction )
 
     def run_test_fail_if_removal_in_hold(self):
         self.assertRaises(
             BoKeepBackendException,
-            self.backend_module.mark_transaction_for_removal,
+            self.backend_plugin.mark_transaction_for_removal,
             self.front_end_id )
 
 class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
@@ -566,38 +566,38 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
                                         fin_trans):
             return backend_id == self.FIRST_BACKEND_ID and \
                 fin_trans == self.fin_trans
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             VERIFY_FAIL, BoKeepBackendException,
             reason_for_backend_verify_fail, test_for_correct_backend_id)
 
         # this should do a VERIFY and a SAVE
         self.verify_known_transaction()
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         self.look_for_actions_from_verify(None)
         self.run_test_of_transaction_verify()
 
     def test_transaction_hold(self):
         # this should just SAVE
-        self.backend_module.mark_transaction_for_hold(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.mark_transaction_for_hold(self.front_end_id)
+        self.backend_plugin.flush_backend()
         self.pop_all_look_for_save()
 
     def test_multi_hold(self):
         # this should just SAVE
         for i in xrange(20):
-            self.backend_module.mark_transaction_for_hold(self.front_end_id)
+            self.backend_plugin.mark_transaction_for_hold(self.front_end_id)
         self.test_transaction_hold()
 
     def test_transaction_dirty_refresh(self):
-        self.backend_module.mark_transaction_dirty(
+        self.backend_plugin.mark_transaction_dirty(
             self.front_end_id, self.transaction)
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsClean(self.front_end_id)
 
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 4) # verify, remove, create, save
 
         self.look_for_verify(actions, self.fin_trans)
@@ -614,14 +614,14 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
             "on remove"
         def test_for_correct_backend_id(backend_mod_self, backend_id):
             return backend_id == self.FIRST_BACKEND_ID
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             REMOVAL_FAIL, BoKeepBackendException,
             reason_for_backend_fail, test_for_correct_backend_id)
 
         self.run_test_of_transaction_remove()
         self.assertTransactionIsDirty(self.front_end_id)
         full_error_string = \
-            self.backend_module.reason_transaction_is_dirty(self.front_end_id)
+            self.backend_plugin.reason_transaction_is_dirty(self.front_end_id)
         self.assert_(full_error_string.endswith(reason_for_backend_fail) )
         self.assert_(full_error_string.startswith(
             "error code: %s"  % BackendDataStateMachine.ERROR_CAN_NOT_REMOVE) )
@@ -634,15 +634,15 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
             "on remove"
         def test_for_correct_backend_id(backend_mod_self, backend_id):
             return backend_id == self.FIRST_BACKEND_ID
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             REMOVAL_RESET, BoKeepBackendResetException,
             reason_for_backend_reset, test_for_correct_backend_id)
 
-        self.backend_module.mark_transaction_for_removal(self.front_end_id)
+        self.backend_plugin.mark_transaction_for_removal(self.front_end_id)
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
 
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 2) # verify, remove
         self.look_for_verify(actions, self.fin_trans)
         self.look_for_remove(actions, self.FIRST_BACKEND_ID)
@@ -650,21 +650,21 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
         self.assertTransactionIsDirty(self.front_end_id)
 
     def test_after_verify_inconsist_triggered_by_verify(self):
-        self.backend_module.program_return(VERIFY, False)
+        self.backend_plugin.program_return(VERIFY, False)
         self.verify_known_transaction()
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         self.look_for_actions_from_verify(False)
         reason_dirty = \
-            self.backend_module.reason_transaction_is_dirty(self.front_end_id)
+            self.backend_plugin.reason_transaction_is_dirty(self.front_end_id)
         self.assert_(reason_dirty.startswith(
                 "error code: %s" % BackendDataStateMachine.ERROR_VERIFY_FAILED
                 ))
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         reason_dirty = \
-            self.backend_module.reason_transaction_is_dirty(self.front_end_id)
+            self.backend_plugin.reason_transaction_is_dirty(self.front_end_id)
         self.assert_(reason_dirty.startswith(
                 "error code: %s" % BackendDataStateMachine.ERROR_VERIFY_FAILED
                 ))
@@ -675,10 +675,10 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
         self.run_test_fail_if_removal_in_hold()
 
         # let it fail the next verification, again
-        self.backend_module.program_return(VERIFY, False)
+        self.backend_plugin.program_return(VERIFY, False)
         self.verify_known_transaction()
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         self.run_test_fail_if_dirty_mark_in_hold()
         self.look_for_actions_from_verify(False)
@@ -691,25 +691,25 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
             backend_mod_self, backend_id, fin_trans):
             return backend_id == self.FIRST_BACKEND_ID and \
                 fin_trans == self.fin_trans
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             VERIFY_FAIL, BoKeepBackendException,
             reason_for_backend_fail, test_for_correct_backend_id)
         self.verify_known_transaction()
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
         self.look_for_actions_from_verify(None)
         self.run_test_of_transaction_verify()
 
     def test_after_verify_inconsist_triggered_by_removal(self):
-        self.backend_module.program_return(VERIFY, False)
+        self.backend_plugin.program_return(VERIFY, False)
         self.remove_known_transaction_and_flush()
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 2) # verify, save
         self.look_for_verify(actions, self.fin_trans, False)
         self.look_for_save(actions)
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.pop_all_look_for_save()
         # can't mark dirty, can't remove normally
         self.run_test_fail_if_dirty_mark_in_hold()
@@ -722,16 +722,16 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
             backend_mod_self, backend_id, fin_trans):
             return backend_id == self.FIRST_BACKEND_ID and \
                 fin_trans == self.fin_trans
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             VERIFY_FAIL, BoKeepBackendException,
             reason_for_backend_fail, test_for_correct_backend_id)
         self.remove_known_transaction_and_flush()
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 2) # verify, save
         self.look_for_verify(actions, self.fin_trans, None)
         self.look_for_save(actions)
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.look_for_normal_remove_sequence()
 
     def test_after_verify_triggered_reset_prior_to_removal(self):
@@ -741,22 +741,22 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
             backend_mod_self, backend_id, fin_trans):
             return backend_id == self.FIRST_BACKEND_ID and \
                 fin_trans == self.fin_trans
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             VERIFY_RESET, BoKeepBackendResetException,
             reason_for_backend_fail, test_for_correct_backend_id)
 
         self.remove_known_transaction_and_flush()
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 1) # verify
         self.look_for_verify(actions, self.fin_trans, None)
         self.assertTransactionIsDirty(self.front_end_id)
         reason_dirty = \
-            self.backend_module.reason_transaction_is_dirty(self.front_end_id)
+            self.backend_plugin.reason_transaction_is_dirty(self.front_end_id)
         self.assert_(reason_dirty.startswith(
                 "error code: %s" % BackendDataStateMachine.ERROR_RESET
                 ))
         #print reason_dirty
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.look_for_normal_remove_sequence()
 
     def test_creation_fail_but_still_save(self):
@@ -765,16 +765,16 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
         def test_for_correct_backend_id(
             backend_mod_self, fin_trans):
             return fin_trans == self.fin_trans
-        self.backend_module.program_failure(
+        self.backend_plugin.program_failure(
             CREATION_FAIL, BoKeepBackendException,
             reason_for_backend_fail, test_for_correct_backend_id)
-        self.backend_module.mark_transaction_dirty(
+        self.backend_plugin.mark_transaction_dirty(
             self.front_end_id, self.transaction)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsClean(self.front_end_id)
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         self.assertEquals(len(actions), 6)
         self.look_for_verify(actions, self.fin_trans)
         self.look_for_remove(actions, self.FIRST_BACKEND_ID)
@@ -786,9 +786,9 @@ class StartWithInsertAndFlushTests(StartWithInsertAndFlushSetup):
 class StartWithInsertFlushAndHoldSetup(StartWithInsertAndFlushSetup):
     def setUp(self):
         StartWithInsertAndFlushSetup.setUp(self)
-        self.backend_module.mark_transaction_for_hold(self.front_end_id)
-        self.backend_module.flush_backend()
-        self.backend_module.pop_actions_queue()
+        self.backend_plugin.mark_transaction_for_hold(self.front_end_id)
+        self.backend_plugin.flush_backend()
+        self.backend_plugin.pop_actions_queue()
 
 
 class InsertFlushAndHoldTest(StartWithInsertFlushAndHoldSetup):
@@ -799,10 +799,10 @@ class InsertFlushAndHoldTest(StartWithInsertFlushAndHoldSetup):
         self.look_for_empty_actions_queue()        
         self.force_remove_known_transaction()
         self.assertTransactionIsDirty(self.front_end_id)
-        self.backend_module.flush_backend()
+        self.backend_plugin.flush_backend()
         self.assertTransactionIsCleanFail(self.front_end_id)
 
-        actions = self.backend_module.pop_actions_queue()
+        actions = self.backend_plugin.pop_actions_queue()
         # expecting REMOVE and SAVE
         self.assertEquals(len(actions), 2)
         self.look_for_remove(actions, self.FIRST_BACKEND_ID)
